.*: Assembler messages:
.*: Error: selected processor does not support system register name 'mpamctl_el1'
.*:  Info: macro invoked from here
.*: Error: selected processor does not support system register name 'mpamctl_el1'
.*:  Info: macro invoked from here
.*: Error: selected processor does not support system register name 'mpamctl_el12'
.*:  Info: macro invoked from here
.*: Error: selected processor does not support system register name 'mpamctl_el12'
.*:  Info: macro invoked from here
.*: Error: selected processor does not support system register name 'mpamctl_el2'
.*:  Info: macro invoked from here
.*: Error: selected processor does not support system register name 'mpamctl_el2'
.*:  Info: macro invoked from here
.*: Error: selected processor does not support system register name 'mpamctl_el3'
.*:  Info: macro invoked from here
.*: Error: selected processor does not support system register name 'mpamctl_el3'
.*:  Info: macro invoked from here
