.*Assembler messages:
.*:8: Error: invalid pcrel_hi offset \(\+2147481600\)
.*:11: Error: invalid pcrel_hi offset \(-2147485697\)
.*:17: Error: invalid pcrel_hi offset \(\+2147481600\)
.*:21: Error: invalid pcrel_hi offset \(-2147485697\)
.*:26: Error: invalid pcrel_hi offset \(\+2147481600\)
.*:30: Error: invalid pcrel_hi offset \(-2147485697\)
