	.gnu_subsection gnu_testing_ba_1_MERGE_AND, optional, uleb128
	.gnu_attribute  0, 1
	.gnu_attribute  1, 1
	.gnu_attribute  2, 1 // Unknown tag
	.gnu_attribute  3, 1 // Unknown tag

	.gnu_subsection gnu_testing_ba_2_MERGE_ADD, optional, ntbs
	.gnu_attribute  0, "foo"
	.gnu_attribute  1, "bar"
	.gnu_attribute  2, "foo2" // Unknown tag
	.gnu_attribute  3, "foo3" // Unknown tag
