	bdep	z0.b, z0.b, z0.b
	bdep	z31.b, z0.b, z0.b
	bdep	z0.b, z31.b, z0.b
	bdep	z0.b, z0.b, z31.b
	bdep	z0.h, z0.h, z0.h
	bdep	z31.h, z0.h, z0.h
	bdep	z0.h, z31.h, z0.h
	bdep	z0.h, z0.h, z31.h
	bdep	z0.s, z0.s, z0.s
	bdep	z31.s, z0.s, z0.s
	bdep	z0.s, z31.s, z0.s
	bdep	z0.s, z0.s, z31.s
	bdep	z0.d, z0.d, z0.d
	bdep	z31.d, z0.d, z0.d
	bdep	z0.d, z31.d, z0.d
	bdep	z0.d, z0.d, z31.d
	bext	z0.b, z0.b, z0.b
	bext	z31.b, z0.b, z0.b
	bext	z0.b, z31.b, z0.b
	bext	z0.b, z0.b, z31.b
	bext	z0.h, z0.h, z0.h
	bext	z31.h, z0.h, z0.h
	bext	z0.h, z31.h, z0.h
	bext	z0.h, z0.h, z31.h
	bext	z0.s, z0.s, z0.s
	bext	z31.s, z0.s, z0.s
	bext	z0.s, z31.s, z0.s
	bext	z0.s, z0.s, z31.s
	bext	z0.d, z0.d, z0.d
	bext	z31.d, z0.d, z0.d
	bext	z0.d, z31.d, z0.d
	bext	z0.d, z0.d, z31.d
	bgrp	z0.b, z0.b, z0.b
	bgrp	z31.b, z0.b, z0.b
	bgrp	z0.b, z31.b, z0.b
	bgrp	z0.b, z0.b, z31.b
	bgrp	z0.h, z0.h, z0.h
	bgrp	z31.h, z0.h, z0.h
	bgrp	z0.h, z31.h, z0.h
	bgrp	z0.h, z0.h, z31.h
	bgrp	z0.s, z0.s, z0.s
	bgrp	z31.s, z0.s, z0.s
	bgrp	z0.s, z31.s, z0.s
	bgrp	z0.s, z0.s, z31.s
	bgrp	z0.d, z0.d, z0.d
	bgrp	z31.d, z0.d, z0.d
	bgrp	z0.d, z31.d, z0.d
	bgrp	z0.d, z0.d, z31.d
